package com.openhis.web.basedatamanage.appservice;

import javax.servlet.http.HttpServletRequest;

import com.core.common.core.domain.R;
import com.openhis.web.basedatamanage.dto.LocationAddOrEditDto;
import com.openhis.web.basedatamanage.dto.LocationPageParam;
import com.openhis.web.common.dto.LocationDto;

import java.util.List;

/**
 * Location 应该服务类
 */
public interface ILocationAppService {
    /**
     * 位置信息
     *
     * @param formList 类型
     * @param pageNo 当前页码
     * @param pageSize 查询条数
     * @param isInHospital 是否为住院
     * @return 位置信息分页列表
     */
    R<?> getLocationTree(List<Integer> formList, Integer pageNo, Integer pageSize, String isInHospital);

    /**
     * 位置信息详情
     *
     * @param locationId 位置信息id
     * @return 位置信息详情
     */
    R<?> getLocationById(Long locationId);

    /**
     * 删除位置信息
     *
     * @param busNo 位置信息编码
     * @return 操作结果
     */
    R<?> deleteLocation(String busNo);

    /**
     * 位置分页列表
     *
     * @param locationPageParam 查询条件
     * @param pageNo 当前页码
     * @param pageSize 查询条数
     * @param searchKey 模糊查询条件
     * @param request 请求
     * @return 位置分页列表
     */
    R<?> getLocationPage(LocationPageParam locationPageParam, String searchKey, Integer pageNo, Integer pageSize,
        HttpServletRequest request);

    /**
     * 新增位置信息
     *
     * @param locationAddOrEditDto 库房位置信息
     * @return 操作结果
     */
    R<?> addLocation(LocationAddOrEditDto locationAddOrEditDto);

    /**
     * 编辑位置信息
     *
     * @param locationAddOrEditDto 库房位置信息
     * @return 操作结果
     */
    R<?> editLocation(LocationAddOrEditDto locationAddOrEditDto);

    /**
     * 位置初始化
     *
     * @return 初始化信息
     */
    R<?> locationInit();

    /**
     * 启用
     *
     * @param locationIdList 位置id
     * @return 操作结果
     */
    R<?> enableLocation(List<Long> locationIdList);

    /**
     * 停用
     *
     * @param locationIdList 位置id
     * @return 操作结果
     */
    R<?> deactivateLocation(List<Long> locationIdList);
}
